==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/EntityRiskPolicyRuleActionRunWorkflowWorkflow.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * This action runs a workflow
 */
@ApiModel(description = "This action runs a workflow")
@JsonPropertyOrder({ EntityRiskPolicyRuleActionRunWorkflowWorkflow.JSON_PROPERTY_ID })
@JsonTypeName("EntityRiskPolicyRuleActionRunWorkflow_workflow")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class EntityRiskPolicyRuleActionRunWorkflowWorkflow implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ID = "id";
    private Integer id;

    public EntityRiskPolicyRuleActionRunWorkflowWorkflow() {
    }

    public EntityRiskPolicyRuleActionRunWorkflowWorkflow id(Integer id) {

        this.id = id;
        return this;
    }

    /**
     * The &#x60;id&#x60; of the workflow that runs.
     *
     * @return id
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The `id` of the workflow that runs.")
    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Integer getId() {
        return id;
    }

    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setId(Integer id) {
        this.id = id;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EntityRiskPolicyRuleActionRunWorkflowWorkflow entityRiskPolicyRuleActionRunWorkflowWorkflow = (EntityRiskPolicyRuleActionRunWorkflowWorkflow) o;
        return Objects.equals(this.id, entityRiskPolicyRuleActionRunWorkflowWorkflow.id);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(id);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EntityRiskPolicyRuleActionRunWorkflowWorkflow {\n");
        sb.append("    id: ").append(toIndentedString(id)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: com/okta/sdk/resource/model/EntityRiskPolicyRuleActionRunWorkflowWorkflow.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * This action runs a workflow
 */
@ApiModel(description = "This action runs a workflow")
@JsonPropertyOrder({ EntityRiskPolicyRuleActionRunWorkflowWorkflow.JSON_PROPERTY_ID })
@JsonTypeName("EntityRiskPolicyRuleActionRunWorkflow_workflow")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class EntityRiskPolicyRuleActionRunWorkflowWorkflow implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ID = "id";
    private Integer id;

    public EntityRiskPolicyRuleActionRunWorkflowWorkflow() {
    }

    public EntityRiskPolicyRuleActionRunWorkflowWorkflow id(Integer id) {

        this.id = id;
        return this;
    }

    /**
     * The &#x60;id&#x60; of the workflow that runs.
     *
     * @return id
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The `id` of the workflow that runs.")
    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Integer getId() {
        return id;
    }

    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setId(Integer id) {
        this.id = id;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EntityRiskPolicyRuleActionRunWorkflowWorkflow entityRiskPolicyRuleActionRunWorkflowWorkflow = (EntityRiskPolicyRuleActionRunWorkflowWorkflow) o;
        return Objects.equals(this.id, entityRiskPolicyRuleActionRunWorkflowWorkflow.id);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(id);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EntityRiskPolicyRuleActionRunWorkflowWorkflow {\n");
        sb.append("    id: ").append(toIndentedString(id)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
